@@ -1,15 +1,25 @@
 """Functions for adding nodes features to a PPI Graph"""
-from typing import Any, Dict
-
-import networkx as nx
-from bioservices import HGNC, UniProt
-
 # %%
 # Graphein
 # Author: Ramon Vinas, Arian Jamasb <arian@jamasb.io>
 # License: MIT
 # Project Website: https://github.com/a-r-j/graphein
 # Code Repository: https://github.com/a-r-j/graphein
+from typing import Any, Dict
+
+import networkx as nx
+
+from graphein.utils.utils import import_message
+
+try:
+    from bioservices import HGNC, UniProt
+except ImportError:
+    import_message(
+        submodule="graphein.ppi.features.nodes_features",
+        package="bioservices",
+        conda_channel="bioconda",
+        pip_install=True,
+    )
 
 
 def add_sequence_to_nodes(n: str, d: Dict[str, Any]):
